//Specification WRX map
//----------Header----------------
//WRL0100 - original WRL
//DMO0100 - original WRL
//WRX0100 - Extended WRL
//WRX0000 - WRX file
//----------File structure--------
//WRL0100, <MAX map> end of file
//DMO0100, <MAX map> end of file
//WRX0100, <MAX map>, <blocks>, <Final block> end of file
//WRX0000, <blocks>, <Final block> end of file
//----------Block structure---------
//1. Block ID - 1 byte
//2. Block size - 4 byte dword - this just Block data size! not all entire block!
//3. Block data - Block size
//----------Known Blocks----------
//01 - Final Block //always!
//       ID - 01 (1 byte)
//       Block size = 0

//10 ($0A) - 1 byte map. //   1  (  )
//       ID - 10 (1 byte)
//       Block size - mapwidth*mapheight+4byte
//       <Block data>
//          mapwidth - 2 byte
//          mapheight - 2 byte
//          map - mapwidth*mapheight*1 byte
//       </Block data>

//11 ($0B)- 2 byte map //   2  (  )
//                //all the same than "1 byte map" but 2 byte indexes

//12 ($0C)- 4 byte map //map indexes 4 bytes width
//       ID - 12 (1 byte)
//       Block size - mapwidth*mapheight*4+4byte
//       <Block data>
//          mapwidth - 2 byte
//          mapheight - 2 byte
//          map - mapwidth*mapheight*4 byte
//       </Block data>

//20 ($14) - 1 byte passtable
//       ID - 20 (1 byte)
//       Block size - itemscount*1byte + 2byte +4byte
//       <Block data>
//          itemscount - 2 byte word 0..65535
//          startfrom - 4 byte integer (default = -1) starfrom=-1 - add to exists mapitems
//          items - itemscount*1 byte (0=land 1=water 2=coast 3=obtacle)
//       </Block data>

//30 ($1E) - 8bit palette minimap (without palette) standart MAX minimap
//       ID - 30 (1 byte)
//       Block size - mapwidth*mapheight+4byte
//       <Block data>
//          width - 2 byte
//          height - 2 byte
//          map - mapwidth*mapheight*1 byte
//       </Block data>

//31 ($1F) - 24 bit minimap
//       ID - 31 (1 byte)
//       Block size - 1byte + filesize
//       <Block data>
//          file type = 1 byte //0=bmp 1=pcx
//          file - filesize*1 byte - all entire file readed from disk. write this block to file and load it.
//       </Block data>

//40 ($28) - 8bit palette sprites (without palette) standart MAX sprites
//       ID - 40 (1 byte)
//       Block size - itemscount*4096byte + 2byte +4byte
//       <Block data>
//          itemscount - 2 byte word 0..65535
//          startfrom - 4 byte integer (default = -1) starfrom=-1 - add to exists mapitems
//          items - itemscount*4096 byte (64*64*1byte)
//       </Block data>

//41 ($29) - 24bit sprites
//       ID - 41 (1 byte)
//       Block size - all size of each file + itemscount*5byte + 2byte +4byte
//       <Block data>
//          itemscount - 2 byte word 0..65535
//          startfrom - 4 byte integer (default = -1) starfrom=-1 - add to exists mapitems
//          <items>
//             file type = 1 byte //0=bmp 1=pcx
//             filesize = 4 byte Dword
//             file - filesize*1 byte - all entire file readed from disk. write this block to file and load it.
//          </items>
//       </Block data>

//42 ($2A) - 24bit sprites with pass and ID (MM map format)
//       ID - 41 (1 byte)
//       Block size - all size of each file + itemscount*(9byte+strings) + 2byte +4byte
//       <Block data>
//          itemscount - 2 byte word 0..65535
//          startfrom - 4 byte integer (default = -1) starfrom=-1 - add to exists mapitems
//          <items>
//             textureID - 4 byte integer
//             filename - Zero teminated string (without extension)
//             pass - 1 byte //0-land 1-water 2-coast 3-blocked
//             overlay - 1 byte //0-No 1-Yes
//             file type = 1 byte //0=bmp 1=pcx
//             filesize = 4 byte Dword
//             file - filesize*1 byte - all entire file readed from disk. write this block to file and load it.
//          </items>
//       </Block data>

//50 ($32) - Palette (RGBA)
//       ID - 50 (1 byte)
//       Block size - 256*4 bytes
//       <Block data>
//          RGBA palette (4 bytes per color) 1.Blue 2.Green 3.Red 4.Reserved
//       </Block data>

//51 ($33) - Palette (RGB) MAX palette
//       ID - 50 (1 byte)
//       Block size - 256*3 bytes
//       <Block data>
//          RGB palette (3 bytes per color) 1.Red 2.Green 3.Blue
//       </Block data>

//60 ($3C) - Masks of sprites for MAX sprites generated by MapGenerator
//                   
//       ID - 60 (1 byte)
//       Block size - itemscount*256byte + 2byte +4byte
//       <Block data>
//          itemscount - 2 byte word 0..65535
//          startfrom - 4 byte integer (default = -1) starfrom=-1 - add to exists mapitems
//          items - itemscount*256 byte (16*16*1byte)
//       </Block data>

//61 ($3D) - 8bit palette PREsprites (without palette) detail masks for standart MAX sprites
//              ,        tileset.
//             ,            tileset'
//             PREsprites   
//       ID - 61 (1 byte)
//       Block size - itemscount*4096byte + 4byte +4byte
//       <Block data>
//          itemscount - 2 byte word 0..65535
//          startfrom - 4 byte integer (default = -1) starfrom=-1 - add to exists mapitems
//          <Items>
//             data:array[0..63,0..63]of byte;
//             kind:byte;//always=1
//             pass:byte;
//             allowAnim:byte;
//             purewater:byte;// 0 -     = 1     = 2      3 =    
//             idInTileset:integer;//   tileset     
//          </Items>
//       </Block data>

//70 ($46) - Tileset
//       ID - 70 (1 byte)
//       Block size - size of file
//       <Block data>
//           file - filesize*1 byte - all entire file readed from disk. write this block to file and load it.
//       </Block data>

//80 ($50) - Comments
//       ID - 80 (1 byte)
//       Block size - size of string
//       <Block data>
//           string - length=Block size without final #0 (non zero-terminated)
//       </Block data>

